django-simple-history
=====================

.. image:: https://github.com/jazzband/django-simple-history/workflows/build/badge.svg?branch=master
   :target: https://github.com/jazzband/django-simple-history/actions?workflow=build
   :alt: Build Status

.. image:: https://readthedocs.org/projects/django-simple-history/badge/?version=latest
   :target: https://django-simple-history.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/codecov/c/github/jazzband/django-simple-history/master.svg
   :target: http://codecov.io/github/jazzband/django-simple-history?branch=master
   :alt: Test Coverage

.. image:: https://img.shields.io/pypi/v/django-simple-history.svg
   :target: https://pypi.python.org/pypi/django-simple-history
   :alt: PyPI Version

.. image:: https://api.codeclimate.com/v1/badges/66cfd94e2db991f2d28a/maintainability
   :target: https://codeclimate.com/github/treyhunner/django-simple-history/maintainability
   :alt: Maintainability

.. image:: https://pepy.tech/badge/django-simple-history
   :target: https://pepy.tech/project/django-simple-history
   :alt: Downloads

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code Style

.. image:: https://jazzband.co/static/img/badge.svg
   :target: https://jazzband.co/
   :alt: Jazzband


django-simple-history stores Django model state on every create/update/delete.

This app supports the following combinations of Django and Python:

==========  =======================
  Django      Python
==========  =======================
2.2         3.6, 3.7, 3.8, 3.9
3.1         3.6, 3.7, 3.8, 3.9
3.2         3.6, 3.7, 3.8, 3.9
==========  =======================

Getting Help
------------

Documentation is available at https://django-simple-history.readthedocs.io/

Pull requests are welcome.  Read the `CONTRIBUTING`_ file for tips on
submitting a pull request.

.. _CONTRIBUTING: https://github.com/jazzband/django-simple-history/blob/master/CONTRIBUTING.rst

License
-------

This project is licensed under the
`BSD 3-Clause license <https://choosealicense.com/licenses/bsd-3-clause/>`_.
